==> prestashop_1.4.0.14.zip: prestashop/modules/prestafraud/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{prestafraud}prestashop>prestafraud_4d0a6a9777a818ecc3b59b9a8ecd0c43'] = '- Merci de choisir votre activité principale -';
$_MODULE['<{prestafraud}prestashop>prestafraud_5a600f5b88f416c470991c6831add13a'] = 'Adultes';
$_MODULE['<{prestafraud}prestashop>prestafraud_0fe4ca3df29658482098bb33a2ff66e5'] = 'Animaux et animaux domestiques';
$_MODULE['<{prestafraud}prestashop>prestafraud_9e4359f35054190eba36e09466e39d01'] = 'Art et Culture';
$_MODULE['<{prestafraud}prestashop>prestafraud_066cd752c82ddc6231a9723b5822a945'] = 'Bébés';
$_MODULE['<{prestafraud}prestashop>prestafraud_41a081c3f3042ac40117cf295350870d'] = 'Beauté et soins personnels';
$_MODULE['<{prestafraud}prestashop>prestafraud_f2b545a8abb14f8706f808a79277c061'] = 'Voitures';
$_MODULE['<{prestafraud}prestashop>prestafraud_39bb2fdc532f8984d8348863c86ebfca'] = 'Matériel informatique et logiciel';
$_MODULE['<{prestafraud}prestashop>prestafraud_801ab24683a4a8c433c6eb40c48bcd9d'] = 'Téléchargement';
$_MODULE['<{prestafraud}prestashop>prestafraud_8bdd8b2357d516da5b81eb16746ba9a9'] = 'Mode et accessoires';
$_MODULE['<{prestafraud}prestashop>prestafraud_33cb31c5505618a808d3bcd7490a793c'] = 'Fleurs, cadeaux et artisanat';
$_MODULE['<{prestafraud}prestashop>prestafraud_0570b6d9de5c37a026e69c6987fc27f6'] = 'Aliments et boissons';
$_MODULE['<{prestafraud}prestashop>prestafraud_4b73b8913afcdf06d9f49c176306d950'] = 'Hi-fi, Photo et Vidéo';
$_MODULE['<{prestafraud}prestashop>prestafraud_2e9d6500d9b2a65985a621f0f0afdeb3'] = 'Maison et jardin';
$_MODULE['<{prestafraud}prestashop>prestafraud_83dd3493957bcd92a37bc39111f670b8'] = 'Home Appliances';
$_MODULE['<{prestafraud}prestashop>prestafraud_565631402af79df42f22a117b0d6f1a5'] = 'Bijoux';
$_MODULE['<{prestafraud}prestashop>prestafraud_18848d605251b3627014c6a58c14c449'] = 'Mobile et Telecom';
$_MODULE['<{prestafraud}prestashop>prestafraud_992a0f0542384f1ee5ef51b7cf4ae6c4'] = 'Services';
$_MODULE['<{prestafraud}prestashop>prestafraud_4ef7205b13f6821177d0dbc2fb90f79e'] = 'Chaussures et accessoires';
$_MODULE['<{prestafraud}prestashop>prestafraud_9503054261b8aeed48e0a3902019b579'] = 'Sport et Loisirs';
$_MODULE['<{prestafraud}prestashop>prestafraud_1fb0f99b55e6c2be35aed72ebe38c245'] = 'Voyage';
$_MODULE['<{prestafraud}prestashop>prestafraud_3e0deb2f1df28a6a13c9c18cc0e1c755'] = 'Chèque';
$_MODULE['<{prestafraud}prestashop>prestafraud_35b4b09d5d0686ec5c2e2cc9f3d9039c'] = 'Virement bancaire';
$_MODULE['<{prestafraud}prestashop>prestafraud_e7f9e382dc50889098cbe56f2554c77b'] = 'Carte de crédit';
$_MODULE['<{prestafraud}prestashop>prestafraud_1cf575079afed29675c47e822bc3d493'] = 'Carte de crédit en plusieurs fois';
$_MODULE['<{prestafraud}prestashop>prestafraud_75b95ea268cb6b5baf7483aafa80d5ad'] = 'Compte prépayé (MoneyBookers, PayPal ...)';
$_MODULE['<{prestafraud}prestashop>prestafraud_79d728437ce932b8194528d10a4e6fe4'] = 'Configuration de Presta-fraude';
$_MODULE['<{prestafraud}prestashop>prestafraud_0fdc6609a76f83fb2def6a9409cc0f38'] = 'Mon magasin n\'a pas encore de compte sur Presta-fraude';
$_MODULE['<{prestafraud}prestashop>prestafraud_3b2aee63259f6dc9b94914884474f8de'] = 'J\'ai déjà un compte';
$_MODULE['<{prestafraud}prestashop>prestafraud_9d5c4ae518b30bacdb69912d87b3406a'] = 'Votre email:';
$_MODULE['<{prestafraud}prestashop>prestafraud_6c3b9b51615d1d57773f25903da2018c'] = 'URL de la boutique:';
$_MODULE['<{prestafraud}prestashop>prestafraud_f6618c3d8174d69a71c47ad556217fd7'] = 'Je suis d\'accord avec les conditions de service Presta-fraude et y adhére sans condition.';
$_MODULE['<{prestafraud}prestashop>prestafraud_42369faa6a6b243aac58683f3874bf99'] = 'Créer un compte';
$_MODULE['<{prestafraud}prestashop>prestafraud_212713efb37cd2f521ee584f1dbb5f0b'] = 'Shop ID:';
$_MODULE['<{prestafraud}prestashop>prestafraud_c6b84387320705147af2f9e79d72c6fc'] = 'Shop Key:';
$_MODULE['<{prestafraud}prestashop>prestafraud_b51cb26e6b60a3ff585ab9f757495c52'] = 'Activité de la boutique:';
$_MODULE['<{prestafraud}prestashop>prestafraud_ab8cba13a061fe8d4a330bcc8d6b0175'] = 'Transporteurs:';
$_MODULE['<{prestafraud}prestashop>prestafraud_914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_MODULE['<{prestafraud}prestashop>prestafraud_fecb07f7ab46e23e9b520a9a9af7b97b'] = 'Type de transporteur';
$_MODULE['<{prestafraud}prestashop>prestafraud_b04ad61ad875f6e7149fdd51c2e60ce2'] = 'Choisissez un type de transporteur...';
$_MODULE['<{prestafraud}prestashop>prestafraud_2edfe3cd8034975c073e23158e976428'] = 'Paiements:';
$_MODULE['<{prestafraud}prestashop>prestafraud_ec51b543e5a38f6044c83f21dce2b23d'] = 'Module de paiement';
$_MODULE['<{prestafraud}prestashop>prestafraud_7c9a3504dd4ce74b8021267ae1802968'] = 'Type de paiement';
$_MODULE['<{prestafraud}prestashop>prestafraud_827638f0be5ae74be04ed494087de714'] = 'Choisissez un type de paiement ...';
$_MODULE['<{prestafraud}prestashop>prestafraud_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{prestafraud}prestashop>prestafraud_16648260e58b4cf9d458e1a197ef43f1'] = 'Email est invalide';
$_MODULE['<{prestafraud}prestashop>prestafraud_cb18f4dc13847e2ed5d69cb936f9b26c'] = 'URL de la boutique n\'est pas valide';
$_MODULE['<{prestafraud}prestashop>prestafraud_2d9f684cd217d62388ac3f4d0345da23'] = 'Presta fraude';
$_MODULE['<{prestafraud}prestashop>prestafraud_438858fbee224aae7b35d9ac18c554c0'] = 'Cette commande n\'a pas été envoyé à Presta fraude.';
$_MODULE['<{prestafraud}prestashop>prestafraud_d0c6a2fa938df84c0ce628de99c97e16'] = 'Notation:';
$_MODULE['<{prestafraud}prestashop>prestafraud_01ae2e552c349bd5608af0f670f8ebc2'] = 'N/A';
$_MODULE['<{prestafraud}prestashop>prestafraud_240f3031f25601fa128bd4e15f0a37de'] = 'Commentaire:';
$_MODULE['<{prestafraud}prestashop>prestafraud_b88011726eba59d6bf37f0fdec202edc'] = 'Rapporter cette commande comme une fraude à PrestaShop';
$_MODULE['<{prestafraud}prestashop>prestafraud_a8bbb000124c9697aa5d63e7e758b64d'] = 'Retrait en magasin';
$_MODULE['<{prestafraud}prestashop>prestafraud_08eb31af908e2244867f6e812f82e935'] = 'Point de retrait, point relais';
$_MODULE['<{prestafraud}prestashop>prestafraud_880f973e4ddae42c6bebd2c31bb977f8'] = 'Livraison lente de plus de 3 jours';
$_MODULE['<{prestafraud}prestashop>prestafraud_b61de91e556aee84e83c3fde8ef67ddc'] = 'Livraison express';

==> prestashop_1.4.1.0.zip: prestashop/modules/prestafraud/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{prestafraud}prestashop>prestafraud_4d0a6a9777a818ecc3b59b9a8ecd0c43'] = '- Merci de choisir votre activité principale -';
$_MODULE['<{prestafraud}prestashop>prestafraud_5a600f5b88f416c470991c6831add13a'] = 'Adultes';
$_MODULE['<{prestafraud}prestashop>prestafraud_0fe4ca3df29658482098bb33a2ff66e5'] = 'Animaux et animaux domestiques';
$_MODULE['<{prestafraud}prestashop>prestafraud_9e4359f35054190eba36e09466e39d01'] = 'Art et Culture';
$_MODULE['<{prestafraud}prestashop>prestafraud_066cd752c82ddc6231a9723b5822a945'] = 'Bébés';
$_MODULE['<{prestafraud}prestashop>prestafraud_41a081c3f3042ac40117cf295350870d'] = 'Beauté et soins personnels';
$_MODULE['<{prestafraud}prestashop>prestafraud_f2b545a8abb14f8706f808a79277c061'] = 'Voitures';
$_MODULE['<{prestafraud}prestashop>prestafraud_39bb2fdc532f8984d8348863c86ebfca'] = 'Matériel informatique et logiciel';
$_MODULE['<{prestafraud}prestashop>prestafraud_801ab24683a4a8c433c6eb40c48bcd9d'] = 'Téléchargement';
$_MODULE['<{prestafraud}prestashop>prestafraud_8bdd8b2357d516da5b81eb16746ba9a9'] = 'Mode et accessoires';
$_MODULE['<{prestafraud}prestashop>prestafraud_33cb31c5505618a808d3bcd7490a793c'] = 'Fleurs, cadeaux et artisanat';
$_MODULE['<{prestafraud}prestashop>prestafraud_0570b6d9de5c37a026e69c6987fc27f6'] = 'Aliments et boissons';
$_MODULE['<{prestafraud}prestashop>prestafraud_4b73b8913afcdf06d9f49c176306d950'] = 'Hi-fi, Photo et Vidéo';
$_MODULE['<{prestafraud}prestashop>prestafraud_2e9d6500d9b2a65985a621f0f0afdeb3'] = 'Maison et jardin';
$_MODULE['<{prestafraud}prestashop>prestafraud_83dd3493957bcd92a37bc39111f670b8'] = 'Home Appliances';
$_MODULE['<{prestafraud}prestashop>prestafraud_565631402af79df42f22a117b0d6f1a5'] = 'Bijoux';
$_MODULE['<{prestafraud}prestashop>prestafraud_18848d605251b3627014c6a58c14c449'] = 'Mobile et Telecom';
$_MODULE['<{prestafraud}prestashop>prestafraud_992a0f0542384f1ee5ef51b7cf4ae6c4'] = 'Services';
$_MODULE['<{prestafraud}prestashop>prestafraud_4ef7205b13f6821177d0dbc2fb90f79e'] = 'Chaussures et accessoires';
$_MODULE['<{prestafraud}prestashop>prestafraud_9503054261b8aeed48e0a3902019b579'] = 'Sport et Loisirs';
$_MODULE['<{prestafraud}prestashop>prestafraud_1fb0f99b55e6c2be35aed72ebe38c245'] = 'Voyage';
$_MODULE['<{prestafraud}prestashop>prestafraud_3e0deb2f1df28a6a13c9c18cc0e1c755'] = 'Chèque';
$_MODULE['<{prestafraud}prestashop>prestafraud_35b4b09d5d0686ec5c2e2cc9f3d9039c'] = 'Virement bancaire';
$_MODULE['<{prestafraud}prestashop>prestafraud_e7f9e382dc50889098cbe56f2554c77b'] = 'Carte de crédit';
$_MODULE['<{prestafraud}prestashop>prestafraud_1cf575079afed29675c47e822bc3d493'] = 'Carte de crédit en plusieurs fois';
$_MODULE['<{prestafraud}prestashop>prestafraud_75b95ea268cb6b5baf7483aafa80d5ad'] = 'Compte prépayé (MoneyBookers, PayPal ...)';
$_MODULE['<{prestafraud}prestashop>prestafraud_688000bea2f79c9ca3d2d1755456024f'] = 'Merci d\'accepter les termes du service.';
$_MODULE['<{prestafraud}prestashop>prestafraud_8dc42e0ea3bedd2c1cc400141540cf62'] = 'Configuration de PrestaShop Security';
$_MODULE['<{prestafraud}prestashop>prestafraud_7e97953add2f27fce07653151ba3e862'] = 'Mon magasin n\'a pas encore de compte sur Prestashop Security';
$_MODULE['<{prestafraud}prestashop>prestafraud_3b2aee63259f6dc9b94914884474f8de'] = 'J\'ai déjà un compte';
$_MODULE['<{prestafraud}prestashop>prestafraud_9d5c4ae518b30bacdb69912d87b3406a'] = 'Votre email:';
$_MODULE['<{prestafraud}prestashop>prestafraud_6c3b9b51615d1d57773f25903da2018c'] = 'URL de la boutique:';
$_MODULE['<{prestafraud}prestashop>prestafraud_36380b31592ff6bf7be94513409871b6'] = 'Je suis d\'accord avec les conditions de service PrestaShop Security et y adhére sans condition.';
$_MODULE['<{prestafraud}prestashop>prestafraud_42369faa6a6b243aac58683f3874bf99'] = 'Créer un compte';
$_MODULE['<{prestafraud}prestashop>prestafraud_212713efb37cd2f521ee584f1dbb5f0b'] = 'Shop ID:';
$_MODULE['<{prestafraud}prestashop>prestafraud_c6b84387320705147af2f9e79d72c6fc'] = 'Shop Key:';
$_MODULE['<{prestafraud}prestashop>prestafraud_b51cb26e6b60a3ff585ab9f757495c52'] = 'Activité de la boutique:';
$_MODULE['<{prestafraud}prestashop>prestafraud_ab8cba13a061fe8d4a330bcc8d6b0175'] = 'Transporteurs:';
$_MODULE['<{prestafraud}prestashop>prestafraud_914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_MODULE['<{prestafraud}prestashop>prestafraud_fecb07f7ab46e23e9b520a9a9af7b97b'] = 'Type de transporteur';
$_MODULE['<{prestafraud}prestashop>prestafraud_b04ad61ad875f6e7149fdd51c2e60ce2'] = 'Choisissez un type de transporteur...';
$_MODULE['<{prestafraud}prestashop>prestafraud_2edfe3cd8034975c073e23158e976428'] = 'Paiements:';
$_MODULE['<{prestafraud}prestashop>prestafraud_ec51b543e5a38f6044c83f21dce2b23d'] = 'Module de paiement';
$_MODULE['<{prestafraud}prestashop>prestafraud_7c9a3504dd4ce74b8021267ae1802968'] = 'Type de paiement';
$_MODULE['<{prestafraud}prestashop>prestafraud_827638f0be5ae74be04ed494087de714'] = 'Choisissez un type de paiement ...';
$_MODULE['<{prestafraud}prestashop>prestafraud_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{prestafraud}prestashop>prestafraud_16648260e58b4cf9d458e1a197ef43f1'] = 'Email est invalide';
$_MODULE['<{prestafraud}prestashop>prestafraud_cb18f4dc13847e2ed5d69cb936f9b26c'] = 'URL de la boutique n\'est pas valide';
$_MODULE['<{prestafraud}prestashop>prestafraud_eed029a9cfe78c1230a654e58fe8b6f8'] = 'PrestaShop Security';
$_MODULE['<{prestafraud}prestashop>prestafraud_950c093b260d7c7709f8ff96e10a6fe0'] = 'Cette commande n\'a pas été envoyé à PrestaShop Security.';
$_MODULE['<{prestafraud}prestashop>prestafraud_d0c6a2fa938df84c0ce628de99c97e16'] = 'Notation:';
$_MODULE['<{prestafraud}prestashop>prestafraud_88183b946cc5f0e8c96b2e66e1c74a7e'] = 'Inconnu';
$_MODULE['<{prestafraud}prestashop>prestafraud_240f3031f25601fa128bd4e15f0a37de'] = 'Commentaire:';
$_MODULE['<{prestafraud}prestashop>prestafraud_b88011726eba59d6bf37f0fdec202edc'] = 'Rapporter cette commande comme une fraude à PrestaShop';
$_MODULE['<{prestafraud}prestashop>prestafraud_a8bbb000124c9697aa5d63e7e758b64d'] = 'Retrait en magasin';
$_MODULE['<{prestafraud}prestashop>prestafraud_08eb31af908e2244867f6e812f82e935'] = 'Point de retrait, point relais';
$_MODULE['<{prestafraud}prestashop>prestafraud_880f973e4ddae42c6bebd2c31bb977f8'] = 'Livraison lente de plus de 3 jours';
$_MODULE['<{prestafraud}prestashop>prestafraud_b61de91e556aee84e83c3fde8ef67ddc'] = 'Livraison express';
